.. include:: ../README.rst


Narrative documentation
-----------------------
Narrative documentation explaining how to use :mod:`dataflake.docbuilder`.

.. toctree::
    :maxdepth: 2

    installation
    usage
    development
    changes


Support
-------
If you need commercial support for this software package, please
visit `https://www.zetwork.com <https://www.zetwork.com/>`_.


Indices and tables
------------------
* :ref:`genindex`
* :ref:`glossary`
